@@ -1,5 +1,4 @@
 # pylint: disable=arguments-differ,missing-function-docstring,missing-class-docstring,unexpected-keyword-arg,no-value-for-parameter
-
 import tensorflow as tf
 import tensorflow_addons as tfa
 
@@ -111,11 +110,16 @@ class TransformerBlock(tf.keras.layers.Layer):
             [
                 tf.keras.layers.Dense(
                     self.mlp_dim,
-                    activation=tf.keras.activations.gelu
-                    if hasattr(tf.keras.activations, "gelu")
-                    else tfa.activations.gelu,
+                    activation="linear",
                     name=f"{self.name}/Dense_0",
                 ),
+                tf.keras.layers.Lambda(
+                    lambda x: tf.keras.activations.gelu(x, approximate=False)
+                )
+                if hasattr(tf.keras.activations, "gelu")
+                else tf.keras.layers.Lambda(
+                    lambda x: tfa.activations.gelu(x, approximate=False)
+                ),
                 tf.keras.layers.Dropout(self.dropout),
                 tf.keras.layers.Dense(input_shape[-1], name=f"{self.name}/Dense_1"),
                 tf.keras.layers.Dropout(self.dropout),
